==> kibana-6.6.1p1.tgz: kibana/src/legacy/core_plugins/apm_oss/index.js <==
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = apmOss;
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

function apmOss(kibana) {
  return new kibana.Plugin({
    id: 'apm_oss',

    config(Joi) {
      return Joi.object({
        // enable plugin
        enabled: Joi.boolean().default(true),

        // Kibana Index pattern
        indexPattern: Joi.string().default('apm-*'),

        // ES Indices
        errorIndices: Joi.string().default('apm-*'),
        onboardingIndices: Joi.string().default('apm-*'),
        spanIndices: Joi.string().default('apm-*'),
        transactionIndices: Joi.string().default('apm-*'),
        metricsIndices: Joi.string().default('apm-*')
      }).default();
    }
  });
}
module.exports = exports['default'];

==> kibana-7.9.1.tgz: kibana/src/legacy/core_plugins/apm_oss/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = apmOss;

var _lodash = _interopRequireDefault(require("lodash"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
function apmOss(kibana) {
  return new kibana.Plugin({
    id: 'apm_oss',

    config(Joi) {
      return Joi.object({
        // enable plugin
        enabled: Joi.boolean().default(true),
        // Kibana Index pattern
        indexPattern: Joi.string().default('apm-*'),
        // ES Indices
        sourcemapIndices: Joi.string().default('apm-*'),
        errorIndices: Joi.string().default('apm-*'),
        transactionIndices: Joi.string().default('apm-*'),
        spanIndices: Joi.string().default('apm-*'),
        metricsIndices: Joi.string().default('apm-*'),
        onboardingIndices: Joi.string().default('apm-*')
      }).default();
    },

    init(server) {
      server.expose('indexPatterns', _lodash.default.uniq(['sourcemapIndices', 'errorIndices', 'transactionIndices', 'spanIndices', 'metricsIndices', 'onboardingIndices'].map(type => server.config().get(`apm_oss.${type}`))));
    }

  });
}

module.exports = exports.default;
